@@ -29,7 +29,7 @@ def doReset():
     wf_job = group(addWFS.si(x) for x in chunk_dict(wfs,10000))
     spell_job = group(addSpells.si(x) for x in chunks(spells,10000))
     trans_job = group(addTrans.si(x) for x in chunks(trans,10000))
-    res = (loadCats.si() |wf_job )()
+    res = (loadCats.si() |spell_job )()
     res.get()
 
 
